"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    db_subnet_group_name: str,
    db_subnet_group_description: str,
    subnet_ids: List,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB subnet group. DB subnet groups must contain at least one subnet in at least two AZs in the Amazon Region.

    Args:
        db_subnet_group_name(str): The name for the DB subnet group. This value is stored as a lowercase string. Constraints: Must contain no more than 255 letters, numbers, periods, underscores, spaces, or hyphens. Must not be default. Example: mySubnetgroup .
        db_subnet_group_description(str): The description for the DB subnet group.
        subnet_ids(List): The EC2 Subnet IDs for the DB subnet group.
        tags(List, optional): The tags to be assigned to the new DB subnet group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.subnet_group.create(
                ctx, db_subnet_group_name=value, db_subnet_group_description=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.subnet_group.create db_subnet_group_name=value, db_subnet_group_description=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="create_db_subnet_group",
        op_kwargs={
            "DBSubnetGroupName": db_subnet_group_name,
            "DBSubnetGroupDescription": db_subnet_group_description,
            "SubnetIds": subnet_ids,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_subnet_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a DB subnet group.  The specified database subnet group must not be associated with any DB instances.

    Args:
        db_subnet_group_name(str): The name of the database subnet group to delete.  You can't delete the default subnet group.  Constraints: Constraints: Must match the name of an existing DBSubnetGroup. Must not be default. Example: mySubnetgroup .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.subnet_group.delete(ctx, db_subnet_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.subnet_group.delete db_subnet_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="delete_db_subnet_group",
        op_kwargs={"DBSubnetGroupName": db_subnet_group_name},
    )


async def describe_all(
    hub,
    ctx,
    db_subnet_group_name: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of DBSubnetGroup descriptions. If a DBSubnetGroupName is specified, the list will contain only the descriptions of the specified DBSubnetGroup. For an overview of CIDR ranges, go to the Wikipedia Tutorial.

    Args:
        db_subnet_group_name(str, optional): The name of the DB subnet group to return details for. Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeDBSubnetGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.subnet_group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.subnet_group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="describe_db_subnet_groups",
        op_kwargs={
            "DBSubnetGroupName": db_subnet_group_name,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub,
    ctx,
    db_subnet_group_name: str,
    subnet_ids: List,
    db_subnet_group_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing DB subnet group. DB subnet groups must contain at least one subnet in at least two AZs in the Amazon Region.

    Args:
        db_subnet_group_name(str): The name for the DB subnet group. This value is stored as a lowercase string. You can't modify the default subnet group. Constraints: Must match the name of an existing DBSubnetGroup. Must not be default. Example: mySubnetgroup .
        db_subnet_group_description(str, optional): The description for the DB subnet group. Defaults to None.
        subnet_ids(List): The EC2 subnet IDs for the DB subnet group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.subnet_group.modify(
                ctx, db_subnet_group_name=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.subnet_group.modify db_subnet_group_name=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="modify_db_subnet_group",
        op_kwargs={
            "DBSubnetGroupName": db_subnet_group_name,
            "DBSubnetGroupDescription": db_subnet_group_description,
            "SubnetIds": subnet_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def index(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Tells the search domain to start indexing its documents using the latest indexing options. This operation must be invoked to activate options whose OptionStatus is RequiresIndexDocuments.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.document.index(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.document.index domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="index_documents",
        op_kwargs={"DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def test(
    hub, ctx, role: str, input_bucket: str, output_bucket: str, topics: List
) -> Dict:
    r"""
    **Autogenerated function**

    The TestRole operation tests the IAM role used to create the pipeline. The TestRole action lets you determine whether the IAM role you are using has sufficient permissions to let Elastic Transcoder perform tasks associated with the transcoding process. The action attempts to assume the specified IAM role, checks read access to the input and output buckets, and tries to send a test notification to Amazon SNS topics that you specify.

    Args:
        role(str): The IAM Amazon Resource Name (ARN) for the role that you want Elastic Transcoder to test.
        input_bucket(str): The Amazon S3 bucket that contains media files to be transcoded. The action attempts to read from this bucket.
        output_bucket(str): The Amazon S3 bucket that Elastic Transcoder writes transcoded media files to. The action attempts to read from this bucket.
        topics(List): The ARNs of one or more Amazon Simple Notification Service (Amazon SNS) topics that you want the action to send a test notification to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.role.test(
                ctx, role=value, input_bucket=value, output_bucket=value, topics=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.role.test role=value, input_bucket=value, output_bucket=value, topics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="test_role",
        op_kwargs={
            "Role": role,
            "InputBucket": input_bucket,
            "OutputBucket": output_bucket,
            "Topics": topics,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    rest_api_id: str,
    name: str = None,
    validate_request_body: bool = None,
    validate_request_parameters: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a ReqeustValidator of a given RestApi.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        name(str, optional): The name of the to-be-created RequestValidator. Defaults to None.
        validate_request_body(bool, optional): A Boolean flag to indicate whether to validate request body according to the configured model schema for the method (true) or not (false). Defaults to None.
        validate_request_parameters(bool, optional): A Boolean flag to indicate whether to validate request parameters, true, or not false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.request_validator.create(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.request_validator.create rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_request_validator",
        op_kwargs={
            "restApiId": rest_api_id,
            "name": name,
            "validateRequestBody": validate_request_body,
            "validateRequestParameters": validate_request_parameters,
        },
    )


async def delete(hub, ctx, rest_api_id: str, request_validator_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a RequestValidator of a given RestApi.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        request_validator_id(str): [Required] The identifier of the RequestValidator to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.request_validator.delete(
                ctx, rest_api_id=value, request_validator_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.request_validator.delete rest_api_id=value, request_validator_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_request_validator",
        op_kwargs={
            "restApiId": rest_api_id,
            "requestValidatorId": request_validator_id,
        },
    )


async def get(hub, ctx, rest_api_id: str, request_validator_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a RequestValidator of a given RestApi.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        request_validator_id(str): [Required] The identifier of the RequestValidator to be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.request_validator.get(
                ctx, rest_api_id=value, request_validator_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.request_validator.get rest_api_id=value, request_validator_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_request_validator",
        op_kwargs={
            "restApiId": rest_api_id,
            "requestValidatorId": request_validator_id,
        },
    )


async def get_all(
    hub, ctx, rest_api_id: str, position: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the RequestValidators collection of a given RestApi.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.request_validator.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.request_validator.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_request_validators",
        op_kwargs={"restApiId": rest_api_id, "position": position, "limit": limit},
    )


async def update(
    hub, ctx, rest_api_id: str, request_validator_id: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a RequestValidator of a given RestApi.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        request_validator_id(str): [Required] The identifier of RequestValidator to be updated.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.request_validator.update(
                ctx, rest_api_id=value, request_validator_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.request_validator.update rest_api_id=value, request_validator_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_request_validator",
        op_kwargs={
            "restApiId": rest_api_id,
            "requestValidatorId": request_validator_id,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(hub, ctx, user_pool_id: str, user: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Disables the user from signing in with the specified external (SAML or social) identity provider. If the user to disable is a Cognito User Pools native username + password user, they are not permitted to use their password to sign-in. If the user to disable is a linked external IdP user, any link between that user and an existing user is removed. The next time the external user (no longer attached to the previously linked DestinationUser) signs in, they must create a new user account. See AdminLinkProviderForUser. This action is enabled only for admin access and requires developer credentials. The ProviderName must match the value specified when creating an IdP for the pool.  To disable a native username + password user, the ProviderName value must be Cognito and the ProviderAttributeName must be Cognito_Subject, with the ProviderAttributeValue being the name that is used in the user pool for the user. The ProviderAttributeName must always be Cognito_Subject for social identity providers. The ProviderAttributeValue must always be the exact subject that was used when the user was originally linked as a source user. For de-linking a SAML identity, there are two scenarios. If the linked identity has not yet been used to sign-in, the ProviderAttributeName and ProviderAttributeValue must be the same values that were used for the SourceUser when the identities were originally linked using  AdminLinkProviderForUser call. (If the linking was done with ProviderAttributeName set to Cognito_Subject, the same applies here). However, if the user has already signed in, the ProviderAttributeName must be Cognito_Subject and ProviderAttributeValue must be the subject of the SAML assertion.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        user(Dict): The user to be disabled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.disable.provider_for_user.admin(
                ctx, user_pool_id=value, user=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.disable.provider_for_user.admin user_pool_id=value, user=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_disable_provider_for_user",
        op_kwargs={"UserPoolId": user_pool_id, "User": user},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, stack_id: str = None, configuration_manager: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the available AWS OpsWorks Stacks agent versions. You must specify a stack ID or a configuration manager. DescribeAgentVersions returns a list of available agent versions for the specified stack or configuration manager.

    Args:
        stack_id(str, optional): The stack ID. Defaults to None.
        configuration_manager(Dict, optional): The configuration manager. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.agent_version.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.agent_version.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_agent_versions",
        op_kwargs={"StackId": stack_id, "ConfigurationManager": configuration_manager},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, name: str, assume_control: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates an interactive session, enabling you to manipulate data in a DataBrew project.

    Args:
        name(str): The name of the project to act upon.
        assume_control(bool, optional): A value that, if true, enables you to take control of a session, even if a different client is currently accessing the project. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.project.session.init.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.project.session.init.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="start_project_session",
        op_kwargs={"Name": name, "AssumeControl": assume_control},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Describes the current Amazon EC2 Auto Scaling resource quotas for your account. When you establish an account, the account has initial quotas on the maximum number of Auto Scaling groups and launch configurations that you can create in a given Region. For more information, see Amazon EC2 Auto Scaling service quotas in the Amazon EC2 Auto Scaling User Guide.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.account_limit.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.account_limit.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_account_limits",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, user_name: str, password: str, password_reset_required: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a password for the specified IAM user. A password allows an IAM user to access Amazon Web Services services through the Management Console. You can use the CLI, the Amazon Web Services API, or the Users page in the IAM console to create a password for any IAM user. Use ChangePassword to update your own existing password in the My Security Credentials page in the Management Console. For more information about managing passwords, see Managing passwords in the IAM User Guide.

    Args:
        user_name(str): The name of the IAM user to create a password for. The user must already exist. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        password(str): The new password for the user. The regex pattern that is used to validate this parameter is a string of characters. That string can include almost any printable ASCII character from the space (\u0020) through the end of the ASCII character range (\u00FF). You can also include the tab (\u0009), line feed (\u000A), and carriage return (\u000D) characters. Any of these characters are valid in a password. However, many tools, such as the Management Console, might restrict the ability to type certain characters because they have special meaning within that tool.
        password_reset_required(bool, optional): Specifies whether the user is required to set a new password on next sign-in. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.login_profile.create(ctx, user_name=value, password=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.login_profile.create user_name=value, password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_login_profile",
        op_kwargs={
            "UserName": user_name,
            "Password": password,
            "PasswordResetRequired": password_reset_required,
        },
    )


async def delete(hub, ctx, user_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the password for the specified IAM user, which terminates the user's ability to access Amazon Web Services services through the Management Console. You can use the CLI, the Amazon Web Services API, or the Users page in the IAM console to delete a password for any IAM user. You can use ChangePassword to update, but not delete, your own password in the My Security Credentials page in the Management Console.   Deleting a user's password does not prevent a user from accessing Amazon Web Services through the command line interface or the API. To prevent all user access, you must also either make any access keys inactive or delete them. For more information about making keys inactive or deleting them, see UpdateAccessKey and DeleteAccessKey.

    Args:
        user_name(str): The name of the user whose password you want to delete. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.login_profile.delete(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.login_profile.delete user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_login_profile",
        op_kwargs={"UserName": user_name},
    )


async def get(hub, ctx, user_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the user name for the specified IAM user. A login profile is created when you create a password for the user to access the Management Console. If the user does not exist or does not have a password, the operation returns a 404 (NoSuchEntity) error. If you create an IAM user with access to the console, the CreateDate reflects the date you created the initial password for the user. If you create an IAM user with programmatic access, and then later add a password for the user to access the Management Console, the CreateDate reflects the initial password creation date. A user with programmatic access does not have a login profile unless you create a password for the user to access the Management Console.

    Args:
        user_name(str): The name of the user whose login profile you want to retrieve. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.login_profile.get(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.login_profile.get user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_login_profile",
        op_kwargs={"UserName": user_name},
    )


async def update(
    hub, ctx, user_name: str, password: str = None, password_reset_required: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Changes the password for the specified IAM user. You can use the CLI, the Amazon Web Services API, or the Users page in the IAM console to change the password for any IAM user. Use ChangePassword to change your own password in the My Security Credentials page in the Management Console. For more information about modifying passwords, see Managing passwords in the IAM User Guide.

    Args:
        user_name(str): The name of the user whose password you want to update. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        password(str, optional): The new password for the specified IAM user. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)   However, the format can be further restricted by the account administrator by setting a password policy on the account. For more information, see UpdateAccountPasswordPolicy. Defaults to None.
        password_reset_required(bool, optional): Allows this new password to be used only once by requiring the specified IAM user to set a new password on next sign-in. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.login_profile.update(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.login_profile.update user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_login_profile",
        op_kwargs={
            "UserName": user_name,
            "Password": password,
            "PasswordResetRequired": password_reset_required,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    end_time: str,
    period: str,
    profiling_group_name: str,
    start_time: str,
    max_results: int = None,
    next_token: str = None,
    order_by: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the start times of the available aggregated profiles of a profiling group for an aggregation period within the specified time range.

    Args:
        end_time(str): The end time of the time range from which to list the profiles.
        max_results(int, optional): The maximum number of profile time results returned by ListProfileTimes in paginated output. When this parameter is used, ListProfileTimes only returns maxResults results in a single page with a nextToken response element. The remaining results of the initial request can be seen by sending another ListProfileTimes request with the returned nextToken value. . Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListProfileTimes request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.   This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        order_by(str, optional): The order (ascending or descending by start time of the profile) to use when listing profiles. Defaults to TIMESTAMP_DESCENDING. . Defaults to None.
        period(str):  The aggregation period. This specifies the period during which an aggregation profile collects posted agent profiles for a profiling group. There are 3 valid values.     P1D — 1 day     PT1H — 1 hour     PT5M — 5 minutes   .
        profiling_group_name(str): The name of the profiling group.
        start_time(str): The start time of the time range from which to list the profiles.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.profile.time.list_all(
                ctx, end_time=value, period=value, profiling_group_name=value, start_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.profile.time.list_all end_time=value, period=value, profiling_group_name=value, start_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="list_profile_times",
        op_kwargs={
            "endTime": end_time,
            "maxResults": max_results,
            "nextToken": next_token,
            "orderBy": order_by,
            "period": period,
            "profilingGroupName": profiling_group_name,
            "startTime": start_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, group_name: str, path: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new group.  For information about the number of groups you can create, see IAM and STS quotas in the IAM User Guide.

    Args:
        path(str, optional):  The path to the group. For more information about paths, see IAM identifiers in the IAM User Guide. This parameter is optional. If it is not included, it defaults to a slash (/). This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        group_name(str): The name of the group to create. Do not include the path in this value. IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource".

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.group.init.create(ctx, group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.group.init.create group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_group",
        op_kwargs={"Path": path, "GroupName": group_name},
    )


async def delete(hub, ctx, group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified IAM group. The group must not contain any users or have any attached policies.

    Args:
        group_name(str): The name of the IAM group to delete. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.group.init.delete(ctx, group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.group.init.delete group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_group",
        op_kwargs={"GroupName": group_name},
    )


async def get(
    hub, ctx, group_name: str, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of IAM users that are in the specified IAM group. You can paginate the results using the MaxItems and Marker parameters.

    Args:
        group_name(str): The name of the group. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.group.init.get(ctx, group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.group.init.get group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_group",
        op_kwargs={"GroupName": group_name, "Marker": marker, "MaxItems": max_items},
    )


async def list_all(
    hub, ctx, path_prefix: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the IAM groups that have the specified path prefix.  You can paginate the results using the MaxItems and Marker parameters.

    Args:
        path_prefix(str, optional):  The path prefix for filtering the results. For example, the prefix /division_abc/subdivision_xyz/ gets all groups whose path starts with /division_abc/subdivision_xyz/. This parameter is optional. If it is not included, it defaults to a slash (/), listing all groups. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.group.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.group.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_groups",
        op_kwargs={"PathPrefix": path_prefix, "Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub, ctx, group_name: str, new_path: str = None, new_group_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Updates the name and/or the path of the specified IAM group.   You should understand the implications of changing a group's path or name. For more information, see Renaming users and groups in the IAM User Guide.   The person making the request (the principal), must have permission to change the role group with the old name and the new name. For example, to change the group named Managers to MGRs, the principal must have a policy that allows them to update both groups. If the principal has permission to update the Managers group, but not the MGRs group, then the update fails. For more information about permissions, see Access management.

    Args:
        group_name(str): Name of the IAM group to update. If you're changing the name of the group, this is the original name. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        new_path(str, optional): New path for the IAM group. Only include this if changing the group's path. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        new_group_name(str, optional): New name for the IAM group. Only include this if changing the group's name. IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource". Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.group.init.update(ctx, group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.group.init.update group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_group",
        op_kwargs={
            "GroupName": group_name,
            "NewPath": new_path,
            "NewGroupName": new_group_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a resource policy that you created in a PutResourcePolicy request.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the rule group or firewall policy whose resource policy you want to delete. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.resource.policy.delete(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.resource.policy.delete resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="delete_resource_policy",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def describe(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a resource policy that you created in a PutResourcePolicy request.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the rule group or firewall policy whose resource policy you want to retrieve. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.resource.policy.describe(
                ctx, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.resource.policy.describe resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="describe_resource_policy",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def put(hub, ctx, resource_arn: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates an AWS Identity and Access Management policy for your rule group or firewall policy. Use this to share rule groups and firewall policies between accounts. This operation works in conjunction with the AWS Resource Access Manager (RAM) service to manage resource sharing for Network Firewall.  Use this operation to create or update a resource policy for your rule group or firewall policy. In the policy, you specify the accounts that you want to share the resource with and the operations that you want the accounts to be able to perform.  When you add an account in the resource policy, you then run the following Resource Access Manager (RAM) operations to access and accept the shared rule group or firewall policy.     GetResourceShareInvitations - Returns the Amazon Resource Names (ARNs) of the resource share invitations.     AcceptResourceShareInvitation - Accepts the share invitation for a specified resource share.    For additional information about resource sharing using RAM, see AWS Resource Access Manager User Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the account that you want to share rule groups and firewall policies with.
        policy(str): The AWS Identity and Access Management policy statement that lists the accounts that you want to share your rule group or firewall policy with and the operations that you want the accounts to be able to perform.  For a rule group resource, you can specify the following operations in the Actions section of the statement:   network-firewall:CreateFirewallPolicy   network-firewall:UpdateFirewallPolicy   network-firewall:ListRuleGroups   For a firewall policy resource, you can specify the following operations in the Actions section of the statement:   network-firewall:CreateFirewall   network-firewall:UpdateFirewall   network-firewall:AssociateFirewallPolicy   network-firewall:ListFirewallPolicies   In the Resource section of the statement, you specify the ARNs for the rule groups and firewall policies that you want to share with the account that you specified in Arn.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.resource.policy.put(
                ctx, resource_arn=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.resource.policy.put resource_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="put_resource_policy",
        op_kwargs={"ResourceArn": resource_arn, "Policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_db_parameter_group_identifier: str,
    target_db_parameter_group_identifier: str,
    target_db_parameter_group_description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified DB parameter group.

    Args:
        source_db_parameter_group_identifier(str): The identifier or ARN for the source DB parameter group. For information about creating an ARN, see  Constructing an Amazon Resource Name (ARN). Constraints:   Must specify a valid DB parameter group.   Must specify a valid DB parameter group identifier, for example my-db-param-group, or a valid ARN.  .
        target_db_parameter_group_identifier(str): The identifier for the copied DB parameter group. Constraints:   Cannot be null, empty, or blank.   Must contain from 1 to 255 letters, numbers, or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Example: my-db-parameter-group .
        target_db_parameter_group_description(str): A description for the copied DB parameter group.
        tags(List, optional): The tags to be assigned to the copied DB parameter group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.parameter.group.copy(
                ctx,
                source_db_parameter_group_identifier=value,
                target_db_parameter_group_identifier=value,
                target_db_parameter_group_description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.parameter.group.copy source_db_parameter_group_identifier=value, target_db_parameter_group_identifier=value, target_db_parameter_group_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="copy_db_parameter_group",
        op_kwargs={
            "SourceDBParameterGroupIdentifier": source_db_parameter_group_identifier,
            "TargetDBParameterGroupIdentifier": target_db_parameter_group_identifier,
            "TargetDBParameterGroupDescription": target_db_parameter_group_description,
            "Tags": tags,
        },
    )


async def create(
    hub,
    ctx,
    db_parameter_group_name: str,
    db_parameter_group_family: str,
    description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB parameter group. A DB parameter group is initially created with the default parameters for the database engine used by the DB instance. To provide custom values for any of the parameters, you must modify the group after creating it using ModifyDBParameterGroup. Once you've created a DB parameter group, you need to associate it with your DB instance using ModifyDBInstance. When you associate a new DB parameter group with a running DB instance, you need to reboot the DB instance without failover for the new DB parameter group and associated settings to take effect.  After you create a DB parameter group, you should wait at least 5 minutes before creating your first DB instance that uses that DB parameter group as the default parameter group. This allows Amazon Neptune to fully complete the create action before the parameter group is used as the default for a new DB instance. This is especially important for parameters that are critical when creating the default database for a DB instance, such as the character set for the default database defined by the character_set_database parameter. You can use the Parameter Groups option of the Amazon Neptune console or the DescribeDBParameters command to verify that your DB parameter group has been created or modified.

    Args:
        db_parameter_group_name(str): The name of the DB parameter group. Constraints:   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens    This value is stored as a lowercase string. .
        db_parameter_group_family(str): The DB parameter group family name. A DB parameter group can be associated with one and only one DB parameter group family, and can be applied only to a DB instance running a database engine and engine version compatible with that DB parameter group family.
        description(str): The description for the DB parameter group.
        tags(List, optional): The tags to be assigned to the new DB parameter group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.parameter.group.create(
                ctx,
                db_parameter_group_name=value,
                db_parameter_group_family=value,
                description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.parameter.group.create db_parameter_group_name=value, db_parameter_group_family=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="create_db_parameter_group",
        op_kwargs={
            "DBParameterGroupName": db_parameter_group_name,
            "DBParameterGroupFamily": db_parameter_group_family,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_parameter_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified DBParameterGroup. The DBParameterGroup to be deleted can't be associated with any DB instances.

    Args:
        db_parameter_group_name(str): The name of the DB parameter group. Constraints:   Must be the name of an existing DB parameter group   You can't delete a default DB parameter group   Cannot be associated with any DB instances  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.parameter.group.delete(
                ctx, db_parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.parameter.group.delete db_parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="delete_db_parameter_group",
        op_kwargs={"DBParameterGroupName": db_parameter_group_name},
    )


async def describe_all(
    hub,
    ctx,
    db_parameter_group_name: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of DBParameterGroup descriptions. If a DBParameterGroupName is specified, the list will contain only the description of the specified DB parameter group.

    Args:
        db_parameter_group_name(str, optional): The name of a specific DB parameter group to return details for. Constraints:   If supplied, must match the name of an existing DBClusterParameterGroup.  . Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeDBParameterGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.parameter.group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.parameter.group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="describe_db_parameter_groups",
        op_kwargs={
            "DBParameterGroupName": db_parameter_group_name,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(hub, ctx, db_parameter_group_name: str, parameters: List) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the parameters of a DB parameter group. To modify more than one parameter, submit a list of the following: ParameterName, ParameterValue, and ApplyMethod. A maximum of 20 parameters can be modified in a single request.  Changes to dynamic parameters are applied immediately. Changes to static parameters require a reboot without failover to the DB instance associated with the parameter group before the change can take effect.   After you modify a DB parameter group, you should wait at least 5 minutes before creating your first DB instance that uses that DB parameter group as the default parameter group. This allows Amazon Neptune to fully complete the modify action before the parameter group is used as the default for a new DB instance. This is especially important for parameters that are critical when creating the default database for a DB instance, such as the character set for the default database defined by the character_set_database parameter. You can use the Parameter Groups option of the Amazon Neptune console or the DescribeDBParameters command to verify that your DB parameter group has been created or modified.

    Args:
        db_parameter_group_name(str): The name of the DB parameter group. Constraints:   If supplied, must match the name of an existing DBParameterGroup.  .
        parameters(List): An array of parameter names, values, and the apply method for the parameter update. At least one parameter name, value, and apply method must be supplied; subsequent arguments are optional. A maximum of 20 parameters can be modified in a single request. Valid Values (for the application method): immediate | pending-reboot   You can use the immediate value with dynamic parameters only. You can use the pending-reboot value for both dynamic and static parameters, and changes are applied when you reboot the DB instance without failover. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.parameter.group.modify(
                ctx, db_parameter_group_name=value, parameters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.parameter.group.modify db_parameter_group_name=value, parameters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="modify_db_parameter_group",
        op_kwargs={
            "DBParameterGroupName": db_parameter_group_name,
            "Parameters": parameters,
        },
    )


async def reset(
    hub,
    ctx,
    db_parameter_group_name: str,
    reset_all_parameters: bool = None,
    parameters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the parameters of a DB parameter group to the engine/system default value. To reset specific parameters, provide a list of the following: ParameterName and ApplyMethod. To reset the entire DB parameter group, specify the DBParameterGroup name and ResetAllParameters parameters. When resetting the entire group, dynamic parameters are updated immediately and static parameters are set to pending-reboot to take effect on the next DB instance restart or RebootDBInstance request.

    Args:
        db_parameter_group_name(str): The name of the DB parameter group. Constraints:   Must match the name of an existing DBParameterGroup.  .
        reset_all_parameters(bool, optional): Specifies whether (true) or not (false) to reset all parameters in the DB parameter group to default values. Default: true . Defaults to None.
        parameters(List, optional): To reset the entire DB parameter group, specify the DBParameterGroup name and ResetAllParameters parameters. To reset specific parameters, provide a list of the following: ParameterName and ApplyMethod. A maximum of 20 parameters can be modified in a single request. Valid Values (for Apply method): pending-reboot . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.parameter.group.reset(
                ctx, db_parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.parameter.group.reset db_parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="reset_db_parameter_group",
        op_kwargs={
            "DBParameterGroupName": db_parameter_group_name,
            "ResetAllParameters": reset_all_parameters,
            "Parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub, ctx, cluster_identifier: str, retention_period: int, manual: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the number of days to retain snapshots in the destination Amazon Web Services Region after they are copied from the source Amazon Web Services Region. By default, this operation only changes the retention period of copied automated snapshots. The retention periods for both new and existing copied automated snapshots are updated with the new retention period. You can set the manual option to change only the retention periods of copied manual snapshots. If you set this option, only newly copied manual snapshots have the new retention period.

    Args:
        cluster_identifier(str): The unique identifier of the cluster for which you want to change the retention period for either automated or manual snapshots that are copied to a destination Amazon Web Services Region. Constraints: Must be the valid name of an existing cluster that has cross-region snapshot copy enabled.
        retention_period(int): The number of days to retain automated snapshots in the destination Amazon Web Services Region after they are copied from the source Amazon Web Services Region. By default, this only changes the retention period of copied automated snapshots.  If you decrease the retention period for automated snapshots that are copied to a destination Amazon Web Services Region, Amazon Redshift deletes any existing automated snapshots that were copied to the destination Amazon Web Services Region and that fall outside of the new retention period. Constraints: Must be at least 1 and no more than 35 for automated snapshots.  If you specify the manual option, only newly copied manual snapshots will have the new retention period.  If you specify the value of -1 newly copied manual snapshots are retained indefinitely. Constraints: The number of days must be either -1 or an integer between 1 and 3,653 for manual snapshots.
        manual(bool, optional): Indicates whether to apply the snapshot retention period to newly copied manual snapshots instead of automated snapshots. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.copy.retention_period.modify(
                ctx, cluster_identifier=value, retention_period=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.copy.retention_period.modify cluster_identifier=value, retention_period=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_snapshot_copy_retention_period",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "RetentionPeriod": retention_period,
            "Manual": manual,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, resource_name: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your ElastiCache resources, with the exception of global replication group. When you add or remove tags on replication groups, those actions will be replicated to all nodes in the replication group. For more information, see Resource-level permissions.  For example, you can use cost-allocation tags to your ElastiCache resources, AWS generates a cost allocation report as a comma-separated value (CSV) file with your usage and costs aggregated by your tags. You can apply tags that represent business categories (such as cost centers, application names, or owners) to organize your costs across multiple services. For more information, see Using Cost Allocation Tags in Amazon ElastiCache in the ElastiCache User Guide.

    Args:
        resource_name(str): The Amazon Resource Name (ARN) of the resource to which the tags are to be added, for example arn:aws:elasticache:us-west-2:0123456789:cluster:myCluster or arn:aws:elasticache:us-west-2:0123456789:snapshot:mySnapshot. ElastiCache resources are cluster and snapshot. For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces.
        tags(List): A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.tags.to_resource.add(
                ctx, resource_name=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.tags.to_resource.add resource_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="add_tags_to_resource",
        op_kwargs={"ResourceName": resource_name, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, id_: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets revisions of the specified workflow. Only the last 100 revisions are stored. If the workflow has been deprecated, this action will return revisions that occurred before the deprecation. This action won't work for workflows that have been deleted.

    Args:
        id_(str): The ID of the workflow. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:workflow:WORKFLOWNAME .
        next_token(str, optional): The string that specifies the next page of results. Use this when you're paginating results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.template.revision.get_all(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.template.revision.get_all id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="get_flow_template_revisions",
        op_kwargs={"id": id_, "nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    job_name: str,
    dataset_arn: str,
    role_arn: str,
    job_output: Dict,
    ingestion_mode: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a job that exports data from your dataset to an Amazon S3 bucket. To allow Amazon Personalize to export the training data, you must specify an service-linked IAM role that gives Amazon Personalize PutObject permissions for your Amazon S3 bucket. For information, see Exporting a dataset in the Amazon Personalize developer guide.   Status  A dataset export job can be in one of the following states:   CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED    To get the status of the export job, call DescribeDatasetExportJob, and specify the Amazon Resource Name (ARN) of the dataset export job. The dataset export is complete when the status shows as ACTIVE. If the status shows as CREATE FAILED, the response includes a failureReason key, which describes why the job failed.

    Args:
        job_name(str): The name for the dataset export job.
        dataset_arn(str): The Amazon Resource Name (ARN) of the dataset that contains the data to export.
        ingestion_mode(str, optional): The data to export, based on how you imported the data. You can choose to export only BULK data that you imported using a dataset import job, only PUT data that you imported incrementally (using the console, PutEvents, PutUsers and PutItems operations), or ALL for both types. The default value is PUT. . Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM service role that has permissions to add data to your output Amazon S3 bucket.
        job_output(Dict): The path to the Amazon S3 bucket where the job's output is stored.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.export_job.create(
                ctx, job_name=value, dataset_arn=value, role_arn=value, job_output=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.export_job.create job_name=value, dataset_arn=value, role_arn=value, job_output=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_dataset_export_job",
        op_kwargs={
            "jobName": job_name,
            "datasetArn": dataset_arn,
            "ingestionMode": ingestion_mode,
            "roleArn": role_arn,
            "jobOutput": job_output,
        },
    )


async def describe(hub, ctx, dataset_export_job_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the dataset export job created by CreateDatasetExportJob, including the export job status.

    Args:
        dataset_export_job_arn(str): The Amazon Resource Name (ARN) of the dataset export job to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.export_job.describe(
                ctx, dataset_export_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.export_job.describe dataset_export_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_dataset_export_job",
        op_kwargs={"datasetExportJobArn": dataset_export_job_arn},
    )


async def list_all(
    hub, ctx, dataset_arn: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of dataset export jobs that use the given dataset. When a dataset is not specified, all the dataset export jobs associated with the account are listed. The response provides the properties for each dataset export job, including the Amazon Resource Name (ARN). For more information on dataset export jobs, see CreateDatasetExportJob. For more information on datasets, see CreateDataset.

    Args:
        dataset_arn(str, optional): The Amazon Resource Name (ARN) of the dataset to list the dataset export jobs for. Defaults to None.
        next_token(str, optional): A token returned from the previous call to ListDatasetExportJobs for getting the next set of dataset export jobs (if they exist). Defaults to None.
        max_results(int, optional): The maximum number of dataset export jobs to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.export_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.export_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_dataset_export_jobs",
        op_kwargs={
            "datasetArn": dataset_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    hsm_type: str,
    subnet_ids: List,
    backup_retention_policy: Dict = None,
    source_backup_id: str = None,
    tag_list: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new AWS CloudHSM cluster.

    Args:
        backup_retention_policy(Dict, optional): A policy that defines how the service retains backups. Defaults to None.
        hsm_type(str): The type of HSM to use in the cluster. Currently the only allowed value is hsm1.medium.
        source_backup_id(str, optional): The identifier (ID) of the cluster backup to restore. Use this value to restore the cluster from a backup instead of creating a new cluster. To find the backup ID, use DescribeBackups. Defaults to None.
        subnet_ids(List): The identifiers (IDs) of the subnets where you are creating the cluster. You must specify at least one subnet. If you specify multiple subnets, they must meet the following criteria:   All subnets must be in the same virtual private cloud (VPC).   You can specify only one subnet per Availability Zone.  .
        tag_list(List, optional): Tags to apply to the CloudHSM cluster during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.cluster.create(ctx, hsm_type=value, subnet_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.cluster.create hsm_type=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="create_cluster",
        op_kwargs={
            "BackupRetentionPolicy": backup_retention_policy,
            "HsmType": hsm_type,
            "SourceBackupId": source_backup_id,
            "SubnetIds": subnet_ids,
            "TagList": tag_list,
        },
    )


async def delete(hub, ctx, cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified AWS CloudHSM cluster. Before you can delete a cluster, you must delete all HSMs in the cluster. To see if the cluster contains any HSMs, use DescribeClusters. To delete an HSM, use DeleteHsm.

    Args:
        cluster_id(str): The identifier (ID) of the cluster that you are deleting. To find the cluster ID, use DescribeClusters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.cluster.delete(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.cluster.delete cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="delete_cluster",
        op_kwargs={"ClusterId": cluster_id},
    )


async def describe_all(
    hub, ctx, filters: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about AWS CloudHSM clusters. This is a paginated operation, which means that each response might contain only a subset of all the clusters. When the response contains only a subset of clusters, it includes a NextToken value. Use this value in a subsequent DescribeClusters request to get more clusters. When you receive a response with no NextToken (or an empty or null value), that means there are no more clusters to get.

    Args:
        filters(Dict, optional): One or more filters to limit the items returned in the response. Use the clusterIds filter to return only the specified clusters. Specify clusters by their cluster identifier (ID). Use the vpcIds filter to return only the clusters in the specified virtual private clouds (VPCs). Specify VPCs by their VPC identifier (ID). Use the states filter to return only clusters that match the specified state. Defaults to None.
        next_token(str, optional): The NextToken value that you received in the previous response. Use this value to get more clusters. Defaults to None.
        max_results(int, optional): The maximum number of clusters to return in the response. When there are more clusters than the number you specify, the response contains a NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.cluster.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.cluster.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="describe_clusters",
        op_kwargs={
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def initialize(
    hub, ctx, cluster_id: str, signed_cert: str, trust_anchor: str
) -> Dict:
    r"""
    **Autogenerated function**

    Claims an AWS CloudHSM cluster by submitting the cluster certificate issued by your issuing certificate authority (CA) and the CA's root certificate. Before you can claim a cluster, you must sign the cluster's certificate signing request (CSR) with your issuing CA. To get the cluster's CSR, use DescribeClusters.

    Args:
        cluster_id(str): The identifier (ID) of the cluster that you are claiming. To find the cluster ID, use DescribeClusters.
        signed_cert(str): The cluster certificate issued (signed) by your issuing certificate authority (CA). The certificate must be in PEM format and can contain a maximum of 5000 characters.
        trust_anchor(str): The issuing certificate of the issuing certificate authority (CA) that issued (signed) the cluster certificate. You must use a self-signed certificate. The certificate used to sign the HSM CSR must be directly available, and thus must be the root certificate. The certificate must be in PEM format and can contain a maximum of 5000 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.cluster.initialize(
                ctx, cluster_id=value, signed_cert=value, trust_anchor=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.cluster.initialize cluster_id=value, signed_cert=value, trust_anchor=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="initialize_cluster",
        op_kwargs={
            "ClusterId": cluster_id,
            "SignedCert": signed_cert,
            "TrustAnchor": trust_anchor,
        },
    )


async def modify(hub, ctx, backup_retention_policy: Dict, cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Modifies AWS CloudHSM cluster.

    Args:
        backup_retention_policy(Dict): A policy that defines how the service retains backups.
        cluster_id(str): The identifier (ID) of the cluster that you want to modify. To find the cluster ID, use DescribeClusters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.cluster.modify(
                ctx, backup_retention_policy=value, cluster_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.cluster.modify backup_retention_policy=value, cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="modify_cluster",
        op_kwargs={
            "BackupRetentionPolicy": backup_retention_policy,
            "ClusterId": cluster_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the state of a pipeline, including the stages and actions.  Values returned in the revisionId and revisionUrl fields indicate the source revision information, such as the commit ID, for the current state.

    Args:
        name(str): The name of the pipeline about which you want to get information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.state.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.state.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="get_pipeline_state",
        op_kwargs={"name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def remove(hub, ctx, resource_id: str, authentication_token: str = None) -> None:
    r"""
    **Autogenerated function**

    Removes all the permissions from the specified resource.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        resource_id(str): The ID of the resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.all_resource_permission.remove(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.all_resource_permission.remove resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="remove_all_resource_permissions",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "ResourceId": resource_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, patch_group: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns high-level aggregated patch compliance state information for a patch group.

    Args:
        patch_group(str): The name of the patch group whose patch snapshot should be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.patch.group.state.describe(ctx, patch_group=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.patch.group.state.describe patch_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_patch_group_state",
        op_kwargs={"PatchGroup": patch_group},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    graph_arn: str,
    accounts: List,
    message: str = None,
    disable_email_notification: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends a request to invite the specified AWS accounts to be member accounts in the behavior graph. This operation can only be called by the administrator account for a behavior graph.   CreateMembers verifies the accounts and then invites the verified accounts. The administrator can optionally specify to not send invitation emails to the member accounts. This would be used when the administrator manages their member accounts centrally. The request provides the behavior graph ARN and the list of accounts to invite. The response separates the requested accounts into two lists:   The accounts that CreateMembers was able to start the verification for. This list includes member accounts that are being verified, that have passed verification and are to be invited, and that have failed verification.   The accounts that CreateMembers was unable to process. This list includes accounts that were already invited to be member accounts in the behavior graph.

    Args:
        graph_arn(str): The ARN of the behavior graph to invite the member accounts to contribute their data to.
        message(str, optional): Customized message text to include in the invitation email message to the invited member accounts. Defaults to None.
        disable_email_notification(bool, optional): if set to true, then the member accounts do not receive email notifications. By default, this is set to false, and the member accounts receive email notifications. Defaults to None.
        accounts(List): The list of AWS accounts to invite to become member accounts in the behavior graph. You can invite up to 50 accounts at a time. For each invited account, the account list contains the account identifier and the AWS account root user email address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.member.create_multiple(
                ctx, graph_arn=value, accounts=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.member.create_multiple graph_arn=value, accounts=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="create_members",
        op_kwargs={
            "GraphArn": graph_arn,
            "Message": message,
            "DisableEmailNotification": disable_email_notification,
            "Accounts": accounts,
        },
    )


async def delete_multiple(hub, ctx, graph_arn: str, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more member accounts from the administrator account's behavior graph. This operation can only be called by a Detective administrator account. That account cannot use DeleteMembers to delete their own account from the behavior graph. To disable a behavior graph, the administrator account uses the DeleteGraph API method.

    Args:
        graph_arn(str): The ARN of the behavior graph to delete members from.
        account_ids(List): The list of AWS account identifiers for the member accounts to delete from the behavior graph. You can delete up to 50 member accounts at a time.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.member.delete_multiple(
                ctx, graph_arn=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.member.delete_multiple graph_arn=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="delete_members",
        op_kwargs={"GraphArn": graph_arn, "AccountIds": account_ids},
    )


async def get_all(hub, ctx, graph_arn: str, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the membership details for specified member accounts for a behavior graph.

    Args:
        graph_arn(str): The ARN of the behavior graph for which to request the member details.
        account_ids(List): The list of AWS account identifiers for the member account for which to return member details. You can request details for up to 50 member accounts at a time. You cannot use GetMembers to retrieve information about member accounts that were removed from the behavior graph.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.member.get_all(
                ctx, graph_arn=value, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.member.get_all graph_arn=value, account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="get_members",
        op_kwargs={"GraphArn": graph_arn, "AccountIds": account_ids},
    )


async def list_all(
    hub, ctx, graph_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the list of member accounts for a behavior graph. Does not return member accounts that were removed from the behavior graph.

    Args:
        graph_arn(str): The ARN of the behavior graph for which to retrieve the list of member accounts.
        next_token(str, optional): For requests to retrieve the next page of member account results, the pagination token that was returned with the previous page of results. The initial request does not include a pagination token. Defaults to None.
        max_results(int, optional): The maximum number of member accounts to include in the response. The total must be less than the overall limit on the number of results to return, which is currently 200. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.member.list_all(ctx, graph_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.member.list_all graph_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="list_members",
        op_kwargs={
            "GraphArn": graph_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    include_availability_zones: bool = None,
    include_relational_database_availability_zones: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all valid regions for Amazon Lightsail. Use the include availability zones parameter to also return the Availability Zones in a region.

    Args:
        include_availability_zones(bool, optional): A Boolean value indicating whether to also include Availability Zones in your get regions request. Availability Zones are indicated with a letter: e.g., us-east-2a. Defaults to None.
        include_relational_database_availability_zones(bool, optional): A Boolean value indicating whether to also include Availability Zones for databases in your get regions request. Availability Zones are indicated with a letter (e.g., us-east-2a). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.region.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.region.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_regions",
        op_kwargs={
            "includeAvailabilityZones": include_availability_zones,
            "includeRelationalDatabaseAvailabilityZones": include_relational_database_availability_zones,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    assessment_id: str,
    control_set_id: str,
    control_id: str,
    control_status: str = None,
    comment_body: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a control within an assessment in Audit Manager.

    Args:
        assessment_id(str):  The identifier for the specified assessment. .
        control_set_id(str):  The identifier for the specified control set. .
        control_id(str):  The identifier for the specified control. .
        control_status(str, optional):  The status of the specified control. . Defaults to None.
        comment_body(str, optional):  The comment body text for the specified control. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.control.init.update(
                ctx, assessment_id=value, control_set_id=value, control_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.control.init.update assessment_id=value, control_set_id=value, control_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="update_assessment_control",
        op_kwargs={
            "assessmentId": assessment_id,
            "controlSetId": control_set_id,
            "controlId": control_id,
            "controlStatus": control_status,
            "commentBody": comment_body,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "by_principal_id"


async def delete(
    hub, ctx, principal_id: str, aws_account_id: str, namespace: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a user identified by its principal ID.

    Args:
        principal_id(str): The principal ID of the user.
        aws_account_id(str): The ID for the Amazon Web Services account; that the user is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.user.by_principal_id_.delete(
                ctx, principal_id=value, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.user.by_principal_id.delete principal_id=value, aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_user_by_principal_id",
        op_kwargs={
            "PrincipalId": principal_id,
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    firewall_policy_arn: str,
    update_token: str = None,
    firewall_arn: str = None,
    firewall_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a FirewallPolicy to a Firewall.  A firewall policy defines how to monitor and manage your VPC network traffic, using a collection of inspection rule groups and other settings. Each firewall requires one firewall policy association, and you can use the same firewall policy for multiple firewalls.

    Args:
        update_token(str, optional): An optional token that you can use for optimistic locking. Network Firewall returns a token to your requests that access the firewall. The token marks the state of the firewall resource at the time of the request.  To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it. To make a conditional change to the firewall, provide the token in your update request. Network Firewall uses the token to ensure that the firewall hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the firewall again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token. . Defaults to None.
        firewall_arn(str, optional): The Amazon Resource Name (ARN) of the firewall. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_name(str, optional): The descriptive name of the firewall. You can't change the name of a firewall after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_policy_arn(str): The Amazon Resource Name (ARN) of the firewall policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.policy.init.associate(
                ctx, firewall_policy_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.policy.init.associate firewall_policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="associate_firewall_policy",
        op_kwargs={
            "UpdateToken": update_token,
            "FirewallArn": firewall_arn,
            "FirewallName": firewall_name,
            "FirewallPolicyArn": firewall_policy_arn,
        },
    )


async def create(
    hub,
    ctx,
    firewall_policy_name: str,
    firewall_policy: Dict,
    description: str = None,
    tags: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates the firewall policy for the firewall according to the specifications.  An AWS Network Firewall firewall policy defines the behavior of a firewall, in a collection of stateless and stateful rule groups and other settings. You can use one firewall policy for multiple firewalls.

    Args:
        firewall_policy_name(str): The descriptive name of the firewall policy. You can't change the name of a firewall policy after you create it.
        firewall_policy(Dict): The rule groups and policy actions to use in the firewall policy.
        description(str, optional): A description of the firewall policy. Defaults to None.
        tags(List, optional): The key:value pairs to associate with the resource. Defaults to None.
        dry_run(bool, optional): Indicates whether you want Network Firewall to just check the validity of the request, rather than run the request.  If set to TRUE, Network Firewall checks whether the request can run successfully, but doesn't actually make the requested changes. The call returns the value that the request would return if you ran it with dry run set to FALSE, but doesn't make additions or changes to your resources. This option allows you to make sure that you have the required permissions to run the request and that your request parameters are valid.  If set to FALSE, Network Firewall makes the requested changes to your resources. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.policy.init.create(
                ctx, firewall_policy_name=value, firewall_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.policy.init.create firewall_policy_name=value, firewall_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="create_firewall_policy",
        op_kwargs={
            "FirewallPolicyName": firewall_policy_name,
            "FirewallPolicy": firewall_policy,
            "Description": description,
            "Tags": tags,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, firewall_policy_name: str = None, firewall_policy_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified FirewallPolicy.

    Args:
        firewall_policy_name(str, optional): The descriptive name of the firewall policy. You can't change the name of a firewall policy after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_policy_arn(str, optional): The Amazon Resource Name (ARN) of the firewall policy. You must specify the ARN or the name, and you can specify both. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.policy.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.policy.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="delete_firewall_policy",
        op_kwargs={
            "FirewallPolicyName": firewall_policy_name,
            "FirewallPolicyArn": firewall_policy_arn,
        },
    )


async def describe(
    hub, ctx, firewall_policy_name: str = None, firewall_policy_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data objects for the specified firewall policy.

    Args:
        firewall_policy_name(str, optional): The descriptive name of the firewall policy. You can't change the name of a firewall policy after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_policy_arn(str, optional): The Amazon Resource Name (ARN) of the firewall policy. You must specify the ARN or the name, and you can specify both. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.policy.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.policy.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="describe_firewall_policy",
        op_kwargs={
            "FirewallPolicyName": firewall_policy_name,
            "FirewallPolicyArn": firewall_policy_arn,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the metadata for the firewall policies that you have defined. Depending on your setting for max results and the number of firewall policies, a single call might not return the full list.

    Args:
        next_token(str, optional): When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Network Firewall returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request. Defaults to None.
        max_results(int, optional): The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a NextToken value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.policy.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.policy.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="list_firewall_policies",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    update_token: str,
    firewall_policy: Dict,
    firewall_policy_arn: str = None,
    firewall_policy_name: str = None,
    description: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the properties of the specified firewall policy.

    Args:
        update_token(str): A token used for optimistic locking. Network Firewall returns a token to your requests that access the firewall policy. The token marks the state of the policy resource at the time of the request.  To make changes to the policy, you provide the token in your request. Network Firewall uses the token to ensure that the policy hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the firewall policy again to get a current copy of it with current token. Reapply your changes as needed, then try the operation again using the new token. .
        firewall_policy_arn(str, optional): The Amazon Resource Name (ARN) of the firewall policy. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_policy_name(str, optional): The descriptive name of the firewall policy. You can't change the name of a firewall policy after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_policy(Dict): The updated firewall policy to use for the firewall. .
        description(str, optional): A description of the firewall policy. Defaults to None.
        dry_run(bool, optional): Indicates whether you want Network Firewall to just check the validity of the request, rather than run the request.  If set to TRUE, Network Firewall checks whether the request can run successfully, but doesn't actually make the requested changes. The call returns the value that the request would return if you ran it with dry run set to FALSE, but doesn't make additions or changes to your resources. This option allows you to make sure that you have the required permissions to run the request and that your request parameters are valid.  If set to FALSE, Network Firewall makes the requested changes to your resources. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.policy.init.update(
                ctx, update_token=value, firewall_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.policy.init.update update_token=value, firewall_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="update_firewall_policy",
        op_kwargs={
            "UpdateToken": update_token,
            "FirewallPolicyArn": firewall_policy_arn,
            "FirewallPolicyName": firewall_policy_name,
            "FirewallPolicy": firewall_policy,
            "Description": description,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    configuration_set_name: str,
    event_destination: Dict = None,
    event_destination_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new event destination in a configuration set.

    Args:
        configuration_set_name(str): ConfigurationSetName.
        event_destination(Dict, optional): An object that defines a single event destination. Defaults to None.
        event_destination_name(str, optional): A name that identifies the event destination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_sms_voice.configuration_set_.event_destination.create(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_sms_voice.configuration_set_.event_destination.create configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-sms-voice",
        operation="create_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestination": event_destination,
            "EventDestinationName": event_destination_name,
        },
    )


async def delete(
    hub, ctx, configuration_set_name: str, event_destination_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an event destination in a configuration set.

    Args:
        configuration_set_name(str): ConfigurationSetName.
        event_destination_name(str): EventDestinationName.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_sms_voice.configuration_set_.event_destination.delete(
                ctx, configuration_set_name=value, event_destination_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_sms_voice.configuration_set_.event_destination.delete configuration_set_name=value, event_destination_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-sms-voice",
        operation="delete_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestinationName": event_destination_name,
        },
    )


async def get_all(hub, ctx, configuration_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination.

    Args:
        configuration_set_name(str): ConfigurationSetName.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_sms_voice.configuration_set_.event_destination.get_all(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_sms_voice.configuration_set_.event_destination.get_all configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-sms-voice",
        operation="get_configuration_set_event_destinations",
        op_kwargs={"ConfigurationSetName": configuration_set_name},
    )


async def update(
    hub,
    ctx,
    configuration_set_name: str,
    event_destination_name: str,
    event_destination: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update an event destination in a configuration set. An event destination is a location that you publish information about your voice calls to. For example, you can log an event to an Amazon CloudWatch destination when a call fails.

    Args:
        configuration_set_name(str): ConfigurationSetName.
        event_destination(Dict, optional): An object that defines a single event destination. Defaults to None.
        event_destination_name(str): EventDestinationName.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_sms_voice.configuration_set_.event_destination.update(
                ctx, configuration_set_name=value, event_destination_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_sms_voice.configuration_set_.event_destination.update configuration_set_name=value, event_destination_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-sms-voice",
        operation="update_configuration_set_event_destination",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "EventDestination": event_destination,
            "EventDestinationName": event_destination_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, fleet_id: str, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Requests remote access to a fleet instance. Remote access is useful for debugging, gathering benchmarking data, or observing activity in real time.  To remotely access an instance, you need credentials that match the operating system of the instance. For a Windows instance, GameLift returns a user name and password as strings for use with a Windows Remote Desktop client. For a Linux instance, GameLift returns a user name and RSA private key, also as strings, for use with an SSH client. The private key must be saved in the proper format to a .pem file before using. If you're making this request using the AWS CLI, saving the secret can be handled as part of the GetInstanceAccess request, as shown in one of the examples for this operation.  To request access to a specific instance, specify the IDs of both the instance and the fleet it belongs to. You can retrieve a fleet's instance IDs by calling DescribeInstances. If successful, an InstanceAccess object is returned that contains the instance's IP address and a set of credentials.  Learn more   Remotely Access Fleet Instances   Debug Fleet Issues   Related actions   DescribeInstances | GetInstanceAccess | DescribeEC2InstanceLimits | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet that contains the instance you want access to. You can use either the fleet ID or ARN value. The fleet can be in any of the following statuses: ACTIVATING, ACTIVE, or ERROR. Fleets with an ERROR status may be accessible for a short time before they are deleted.
        instance_id(str): A unique identifier for the instance you want to get access to. You can access an instance in any status.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.instance.access.get(
                ctx, fleet_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.instance.access.get fleet_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="get_instance_access",
        op_kwargs={"FleetId": fleet_id, "InstanceId": instance_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, worker_id: str, reason: str) -> Dict:
    r"""
    **Autogenerated function**

    The CreateWorkerBlock operation allows you to prevent a Worker from working on your HITs. For example, you can block a Worker who is producing poor quality work. You can block up to 100,000 Workers.

    Args:
        worker_id(str): The ID of the Worker to block.
        reason(str): A message explaining the reason for blocking the Worker. This parameter enables you to keep track of your Workers. The Worker does not see this message.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.worker.block.create(ctx, worker_id=value, reason=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.worker.block.create worker_id=value, reason=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="create_worker_block",
        op_kwargs={"WorkerId": worker_id, "Reason": reason},
    )


async def delete(hub, ctx, worker_id: str, reason: str = None) -> Dict:
    r"""
    **Autogenerated function**

    The DeleteWorkerBlock operation allows you to reinstate a blocked Worker to work on your HITs. This operation reverses the effects of the CreateWorkerBlock operation. You need the Worker ID to use this operation. If the Worker ID is missing or invalid, this operation fails and returns the message “WorkerId is invalid.” If the specified Worker is not blocked, this operation returns successfully.

    Args:
        worker_id(str): The ID of the Worker to unblock.
        reason(str, optional): A message that explains the reason for unblocking the Worker. The Worker does not see this message. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.worker.block.delete(ctx, worker_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.worker.block.delete worker_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="delete_worker_block",
        op_kwargs={"WorkerId": worker_id, "Reason": reason},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    The ListWorkersBlocks operation retrieves a list of Workers who are blocked from working on your HITs.

    Args:
        next_token(str, optional): Pagination token. Defaults to None.
        max_results(int, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.worker.block.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.worker.block.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="list_worker_blocks",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, organization_id: str, endpoint: str, protocol: str, subscription_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Configure Amazon WorkDocs to use Amazon SNS notifications. The endpoint receives a confirmation message, and must confirm the subscription. For more information, see Subscribe to Notifications in the Amazon WorkDocs Developer Guide.

    Args:
        organization_id(str): The ID of the organization.
        endpoint(str): The endpoint to receive the notifications. If the protocol is HTTPS, the endpoint is a URL that begins with https.
        protocol(str): The protocol to use. The supported value is https, which delivers JSON-encoded messages using HTTPS POST.
        subscription_type(str): The notification type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.notification_subscription.create(
                ctx, organization_id=value, endpoint=value, protocol=value, subscription_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.notification_subscription.create organization_id=value, endpoint=value, protocol=value, subscription_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="create_notification_subscription",
        op_kwargs={
            "OrganizationId": organization_id,
            "Endpoint": endpoint,
            "Protocol": protocol,
            "SubscriptionType": subscription_type,
        },
    )


async def delete(hub, ctx, subscription_id: str, organization_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified subscription from the specified organization.

    Args:
        subscription_id(str): The ID of the subscription.
        organization_id(str): The ID of the organization.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.notification_subscription.delete(
                ctx, subscription_id=value, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.notification_subscription.delete subscription_id=value, organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="delete_notification_subscription",
        op_kwargs={
            "SubscriptionId": subscription_id,
            "OrganizationId": organization_id,
        },
    )


async def describe_all(
    hub, ctx, organization_id: str, marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the specified notification subscriptions.

    Args:
        organization_id(str): The ID of the organization.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.notification_subscription.describe_all(
                ctx, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.notification_subscription.describe_all organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="describe_notification_subscriptions",
        op_kwargs={"OrganizationId": organization_id, "Marker": marker, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, feature_set: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates an AWS organization. The account whose user is calling the CreateOrganization operation automatically becomes the management account of the new organization. This operation must be called using credentials from the account that is to become the new organization's management account. The principal must also have the relevant IAM permissions. By default (or if you set the FeatureSet parameter to ALL), the new organization is created with all features enabled and service control policies automatically enabled in the root. If you instead choose to create the organization supporting only the consolidated billing features by setting the FeatureSet parameter to CONSOLIDATED_BILLING", no policy types are enabled by default, and you can't use organization policies

    Args:
        feature_set(str, optional): Specifies the feature set supported by the new organization. Each feature set supports different levels of functionality.    CONSOLIDATED_BILLING: All member accounts have their bills consolidated to and paid by the management account. For more information, see Consolidated billing in the AWS Organizations User Guide.   The consolidated billing feature subset isn't available for organizations in the AWS GovCloud (US) Region.    ALL: In addition to all the features supported by the consolidated billing feature set, the management account can also apply any policy type to any member account in the organization. For more information, see All features in the AWS Organizations User Guide.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.organization.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.organization.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="create_organization",
        op_kwargs={"FeatureSet": feature_set},
    )


async def delete(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Deletes the organization. You can delete an organization only by using credentials from the management account. The organization must be empty of member accounts.

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.organization.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.organization.delete
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="organizations", operation="delete_organization", op_kwargs={}
    )


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the organization that the user's account belongs to. This operation can be called from any account in the organization.  Even if a policy type is shown as available in the organization, you can disable it separately at the root level with DisablePolicyType. Use ListRoots to see the status of policy types for a specified root.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.organization.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.organization.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="describe_organization",
        op_kwargs={},
    )


async def leave(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Removes a member account from its parent organization. This version of the operation is performed by the account that wants to leave. To remove a member account as a user in the management account, use RemoveAccountFromOrganization instead. This operation can be called only from a member account in the organization.    The management account in an organization with all features enabled can set service control policies (SCPs) that can restrict what administrators of member accounts can do. This includes preventing them from successfully calling LeaveOrganization and leaving the organization.   You can leave an organization as a member account only if the account is configured with the information required to operate as a standalone account. When you create an account in an organization using the AWS Organizations console, API, or CLI commands, the information required of standalone accounts is not automatically collected. For each account that you want to make standalone, you must perform the following steps. If any of the steps are already completed for this account, that step doesn't appear.   Choose a support plan   Provide and verify the required contact information   Provide a current payment method   AWS uses the payment method to charge for any billable (not free tier) AWS activity that occurs while the account isn't attached to an organization. Follow the steps at  To leave an organization when all required account information has not yet been provided in the AWS Organizations User Guide.    The account that you want to leave must not be a delegated administrator account for any AWS service enabled for your organization. If the account is a delegated administrator, you must first change the delegated administrator account to another account that is remaining in the organization.   You can leave an organization only after you enable IAM user access to billing in your account. For more information, see Activating Access to the Billing and Cost Management Console in the AWS Billing and Cost Management User Guide.    After the account leaves the organization, all tags that were attached to the account object in the organization are deleted. AWS accounts outside of an organization do not support tags.   A newly created account has a waiting period before it can be removed from its organization. If you get an error that indicates that a wait period is required, then try again in a few days.

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.organization.leave(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.organization.leave
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="organizations", operation="leave_organization", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    engine: str,
    engine_version: str = None,
    db_instance_class: str = None,
    license_model: str = None,
    availability_zone_group: str = None,
    vpc: bool = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of orderable DB instance options for the specified engine.

    Args:
        engine(str): The name of the engine to retrieve DB instance options for. Valid Values:     aurora (for MySQL 5.6-compatible Aurora)    aurora-mysql (for MySQL 5.7-compatible Aurora)    aurora-postgresql     mariadb     mysql     oracle-ee     oracle-ee-cdb     oracle-se2     oracle-se2-cdb     postgres     sqlserver-ee     sqlserver-se     sqlserver-ex     sqlserver-web   .
        engine_version(str, optional): The engine version filter value. Specify this parameter to show only the available offerings matching the specified engine version. Defaults to None.
        db_instance_class(str, optional): The DB instance class filter value. Specify this parameter to show only the available offerings matching the specified DB instance class. Defaults to None.
        license_model(str, optional): The license model filter value. Specify this parameter to show only the available offerings matching the specified license model. Defaults to None.
        availability_zone_group(str, optional): The Availability Zone group associated with a Local Zone. Specify this parameter to retrieve available offerings for the Local Zones in the group. Omit this parameter to show the available offerings in the specified Amazon Web Services Region. Defaults to None.
        vpc(bool, optional): A value that indicates whether to show only VPC or non-VPC offerings. Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords . . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.orderable_db_instance_option.describe_all(ctx, engine=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.orderable_db_instance_option.describe_all engine=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_orderable_db_instance_options",
        op_kwargs={
            "Engine": engine,
            "EngineVersion": engine_version,
            "DBInstanceClass": db_instance_class,
            "LicenseModel": license_model,
            "AvailabilityZoneGroup": availability_zone_group,
            "Vpc": vpc,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    connection_arn: str,
    invocation_endpoint: str,
    http_method: str,
    description: str = None,
    invocation_rate_limit_per_second: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an API destination, which is an HTTP invocation endpoint configured as a target for events.

    Args:
        name(str): The name for the API destination to create.
        description(str, optional): A description for the API destination to create. Defaults to None.
        connection_arn(str): The ARN of the connection to use for the API destination. The destination endpoint must support the authorization type specified for the connection.
        invocation_endpoint(str): The URL to the HTTP invocation endpoint for the API destination.
        http_method(str): The method to use for the request to the HTTP invocation endpoint.
        invocation_rate_limit_per_second(int, optional): The maximum number of requests per second to send to the HTTP invocation endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.api_destination.create(
                ctx, name=value, connection_arn=value, invocation_endpoint=value, http_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.api_destination.create name=value, connection_arn=value, invocation_endpoint=value, http_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="create_api_destination",
        op_kwargs={
            "Name": name,
            "Description": description,
            "ConnectionArn": connection_arn,
            "InvocationEndpoint": invocation_endpoint,
            "HttpMethod": http_method,
            "InvocationRateLimitPerSecond": invocation_rate_limit_per_second,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified API destination.

    Args:
        name(str): The name of the destination to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.api_destination.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.api_destination.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="delete_api_destination",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details about an API destination.

    Args:
        name(str): The name of the API destination to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.api_destination.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.api_destination.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="describe_api_destination",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub,
    ctx,
    name_prefix: str = None,
    connection_arn: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of API destination in the account in the current Region.

    Args:
        name_prefix(str, optional): A name prefix to filter results returned. Only API destinations with a name that starts with the prefix are returned. Defaults to None.
        connection_arn(str, optional): The ARN of the connection specified for the API destination. Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        limit(int, optional): The maximum number of API destinations to include in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.api_destination.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.api_destination.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_api_destinations",
        op_kwargs={
            "NamePrefix": name_prefix,
            "ConnectionArn": connection_arn,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def update(
    hub,
    ctx,
    name: str,
    description: str = None,
    connection_arn: str = None,
    invocation_endpoint: str = None,
    http_method: str = None,
    invocation_rate_limit_per_second: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an API destination.

    Args:
        name(str): The name of the API destination to update.
        description(str, optional): The name of the API destination to update. Defaults to None.
        connection_arn(str, optional): The ARN of the connection to use for the API destination. Defaults to None.
        invocation_endpoint(str, optional): The URL to the endpoint to use for the API destination. Defaults to None.
        http_method(str, optional): The method to use for the API destination. Defaults to None.
        invocation_rate_limit_per_second(int, optional): The maximum number of invocations per second to send to the API destination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.api_destination.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.api_destination.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="update_api_destination",
        op_kwargs={
            "Name": name,
            "Description": description,
            "ConnectionArn": connection_arn,
            "InvocationEndpoint": invocation_endpoint,
            "HttpMethod": http_method,
            "InvocationRateLimitPerSecond": invocation_rate_limit_per_second,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub, ctx, conformance_pack_names: List, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns compliance details for the conformance pack based on the cumulative compliance results of all the rules in that conformance pack.

    Args:
        conformance_pack_names(List): Names of conformance packs.
        limit(int, optional): The maximum number of conformance packs returned on each page. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.conformance_pack.compliance.summary.get(
                ctx, conformance_pack_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.conformance_pack.compliance.summary.get conformance_pack_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_conformance_pack_compliance_summary",
        op_kwargs={
            "ConformancePackNames": conformance_pack_names,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def acknowledge(hub, ctx, job_id: str, nonce: str, client_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Confirms a job worker has received the specified job. Used for partner actions only.

    Args:
        job_id(str): The unique system-generated ID of the job.
        nonce(str): A system-generated random number that AWS CodePipeline uses to ensure that the job is being worked on by only one job worker. Get this number from the response to a GetThirdPartyJobDetails request.
        client_token(str): The clientToken portion of the clientId and clientToken pair used to verify that the calling entity is allowed access to the job and its details.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.third_party_job.init.acknowledge(
                ctx, job_id=value, nonce=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.third_party_job.init.acknowledge job_id=value, nonce=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="acknowledge_third_party_job",
        op_kwargs={"jobId": job_id, "nonce": nonce, "clientToken": client_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    account_id: str,
    vault_name: str,
    limit: str = None,
    marker: str = None,
    statuscode: str = None,
    completed: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation lists jobs for a vault, including jobs that are in-progress and jobs that have recently finished. The List Job operation returns a list of these jobs sorted by job initiation time.  Amazon Glacier retains recently completed jobs for a period before deleting them; however, it eventually removes completed jobs. The output of completed jobs can be retrieved. Retaining completed jobs for a period of time after they have completed enables you to get a job output in the event you miss the job completion notification or your first attempt to download it fails. For example, suppose you start an archive retrieval job to download an archive. After the job completes, you start to download the archive but encounter a network error. In this scenario, you can retry and download the archive while the job exists.  The List Jobs operation supports pagination. You should always check the response Marker field. If there are no more jobs to list, the Marker field is set to null. If there are more jobs to list, the Marker field is set to a non-null value, which you can use to continue the pagination of the list. To return a list of jobs that begins at a specific job, set the marker request parameter to the Marker value for that job that you obtained from a previous List Jobs request. You can set a maximum limit for the number of jobs returned in the response by specifying the limit parameter in the request. The default limit is 50. The number of jobs returned might be fewer than the limit, but the number of returned jobs never exceeds the limit. Additionally, you can filter the jobs list returned by specifying the optional statuscode parameter or completed parameter, or both. Using the statuscode parameter, you can specify to return only jobs that match either the InProgress, Succeeded, or Failed status. Using the completed parameter, you can specify to return only jobs that were completed (true) or jobs that were not completed (false). For more information about using this operation, see the documentation for the underlying REST API List Jobs.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        vault_name(str): The name of the vault.
        limit(str, optional): The maximum number of jobs to be returned. The default limit is 50. The number of jobs returned might be fewer than the specified limit, but the number of returned jobs never exceeds the limit. Defaults to None.
        marker(str, optional): An opaque string used for pagination. This value specifies the job at which the listing of jobs should begin. Get the marker value from a previous List Jobs response. You only need to include the marker if you are continuing the pagination of results started in a previous List Jobs request. Defaults to None.
        statuscode(str, optional): The type of job status to return. You can specify the following values: InProgress, Succeeded, or Failed. Defaults to None.
        completed(str, optional): The state of the jobs to return. You can specify true or false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.jobs.list(ctx, account_id=value, vault_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.jobs.list account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="list_jobs",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "limit": limit,
            "marker": marker,
            "statuscode": statuscode,
            "completed": completed,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, domain_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all packages associated with the Amazon ES domain.

    Args:
        domain_name(str): The name of the domain for which you want to list associated packages.
        max_results(int, optional): Limits results to a maximum number of packages. Defaults to None.
        next_token(str, optional): Used for pagination. Only necessary if a previous API call includes a non-null NextToken value. If provided, returns results for the next page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.package.for_domain.list(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.package.for_domain.list domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="list_packages_for_domain",
        op_kwargs={
            "DomainName": domain_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    service_name: str,
    power: str,
    scale: int,
    tags: List = None,
    public_domain_names: Dict = None,
    deployment: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Lightsail container service. A Lightsail container service is a compute resource to which you can deploy containers. For more information, see Container services in Amazon Lightsail in the Lightsail Dev Guide.

    Args:
        service_name(str): The name for the container service. The name that you specify for your container service will make up part of its default domain. The default domain of a container service is typically https://<ServiceName>.<RandomGUID>.<AWSRegion>.cs.amazonlightsail.com. If the name of your container service is container-service-1, and it's located in the US East (Ohio) AWS region (us-east-2), then the domain for your container service will be like the following example: https://container-service-1.ur4EXAMPLE2uq.us-east-2.cs.amazonlightsail.com  The following are the requirements for container service names:   Must be unique within each AWS Region in your Lightsail account.   Must contain 1 to 63 characters.   Must contain only alphanumeric characters and hyphens.   A hyphen (-) can separate words but cannot be at the start or end of the name.  .
        power(str): The power specification for the container service. The power specifies the amount of memory, vCPUs, and base monthly cost of each node of the container service. The power and scale of a container service makes up its configured capacity. To determine the monthly price of your container service, multiply the base price of the power with the scale (the number of nodes) of the service. Use the GetContainerServicePowers action to get a list of power options that you can specify using this parameter, and their base monthly cost.
        scale(int): The scale specification for the container service. The scale specifies the allocated compute nodes of the container service. The power and scale of a container service makes up its configured capacity. To determine the monthly price of your container service, multiply the base price of the power with the scale (the number of nodes) of the service.
        tags(List, optional): The tag keys and optional values to add to the certificate during create. Use the TagResource action to tag a resource after it's created. For more information about tags in Lightsail, see the Amazon Lightsail Developer Guide. Defaults to None.
        public_domain_names(Dict, optional): The public domain names to use with the container service, such as example.com and www.example.com. You can specify up to four public domain names for a container service. The domain names that you specify are used when you create a deployment with a container configured as the public endpoint of your container service. If you don't specify public domain names, then you can use the default domain of the container service.  You must create and validate an SSL/TLS certificate before you can use public domain names with your container service. Use the CreateCertificate action to create a certificate for the public domain names you want to use with your container service.  You can specify public domain names using a string to array map as shown in the example later on this page. Defaults to None.
        deployment(Dict, optional): An object that describes a deployment for the container service. A deployment specifies the containers that will be launched on the container service and their settings, such as the ports to open, the environment variables to apply, and the launch command to run. It also specifies the container that will serve as the public endpoint of the deployment and its settings, such as the HTTP or HTTPS port to use, and the health check configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.init.create(
                ctx, service_name=value, power=value, scale=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.init.create service_name=value, power=value, scale=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_container_service",
        op_kwargs={
            "serviceName": service_name,
            "power": power,
            "scale": scale,
            "tags": tags,
            "publicDomainNames": public_domain_names,
            "deployment": deployment,
        },
    )


async def delete(hub, ctx, service_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes your Amazon Lightsail container service.

    Args:
        service_name(str): The name of the container service to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.init.delete(ctx, service_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.init.delete service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_container_service",
        op_kwargs={"serviceName": service_name},
    )


async def get_all(hub, ctx, service_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about one or more of your Amazon Lightsail container services.

    Args:
        service_name(str, optional): The name of the container service for which to return information. When omitted, the response includes all of your container services in the AWS Region where the request is made. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_container_services",
        op_kwargs={"serviceName": service_name},
    )


async def update(
    hub,
    ctx,
    service_name: str,
    power: str = None,
    scale: int = None,
    is_disabled: bool = None,
    public_domain_names: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration of your Amazon Lightsail container service, such as its power, scale, and public domain names.

    Args:
        service_name(str): The name of the container service to update.
        power(str, optional): The power for the container service. The power specifies the amount of memory, vCPUs, and base monthly cost of each node of the container service. The power and scale of a container service makes up its configured capacity. To determine the monthly price of your container service, multiply the base price of the power with the scale (the number of nodes) of the service. Use the GetContainerServicePowers action to view the specifications of each power option. Defaults to None.
        scale(int, optional): The scale for the container service. The scale specifies the allocated compute nodes of the container service. The power and scale of a container service makes up its configured capacity. To determine the monthly price of your container service, multiply the base price of the power with the scale (the number of nodes) of the service. Defaults to None.
        is_disabled(bool, optional): A Boolean value to indicate whether the container service is disabled. Defaults to None.
        public_domain_names(Dict, optional): The public domain names to use with the container service, such as example.com and www.example.com. You can specify up to four public domain names for a container service. The domain names that you specify are used when you create a deployment with a container configured as the public endpoint of your container service. If you don't specify public domain names, then you can use the default domain of the container service.  You must create and validate an SSL/TLS certificate before you can use public domain names with your container service. Use the CreateCertificate action to create a certificate for the public domain names you want to use with your container service.  You can specify public domain names using a string to array map as shown in the example later on this page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.init.update(ctx, service_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.init.update service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="update_container_service",
        op_kwargs={
            "serviceName": service_name,
            "power": power,
            "scale": scale,
            "isDisabled": is_disabled,
            "publicDomainNames": public_domain_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    subnet_id: str,
    assign_ipv6_address_on_creation: Dict = None,
    map_public_ip_on_launch: Dict = None,
    map_customer_owned_ip_on_launch: Dict = None,
    customer_owned_ipv4_pool: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Modifies a subnet attribute. You can only modify one attribute at a time.

    Args:
        assign_ipv6_address_on_creation(Dict, optional): Specify true to indicate that network interfaces created in the specified subnet should be assigned an IPv6 address. This includes a network interface that's created when launching an instance into the subnet (the instance therefore receives an IPv6 address).  If you enable the IPv6 addressing feature for your subnet, your network interface or instance only receives an IPv6 address if it's created using version 2016-11-15 or later of the Amazon EC2 API. Defaults to None.
        map_public_ip_on_launch(Dict, optional): Specify true to indicate that network interfaces attached to instances created in the specified subnet should be assigned a public IPv4 address. Defaults to None.
        subnet_id(str): The ID of the subnet.
        map_customer_owned_ip_on_launch(Dict, optional): Specify true to indicate that network interfaces attached to instances created in the specified subnet should be assigned a customer-owned IPv4 address. When this value is true, you must specify the customer-owned IP pool using CustomerOwnedIpv4Pool. Defaults to None.
        customer_owned_ipv4_pool(str, optional): The customer-owned IPv4 address pool associated with the subnet. You must set this value when you specify true for MapCustomerOwnedIpOnLaunch. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.subnet.attribute.modify(ctx, subnet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.subnet.attribute.modify subnet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_subnet_attribute",
        op_kwargs={
            "AssignIpv6AddressOnCreation": assign_ipv6_address_on_creation,
            "MapPublicIpOnLaunch": map_public_ip_on_launch,
            "SubnetId": subnet_id,
            "MapCustomerOwnedIpOnLaunch": map_customer_owned_ip_on_launch,
            "CustomerOwnedIpv4Pool": customer_owned_ipv4_pool,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    device_arn: str,
    event_type: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the device event history, including device connection status, for up to 30 days.

    Args:
        device_arn(str): The ARN of a device.
        event_type(str, optional): The event type to filter device events. If EventType isn't specified, this returns a list of all device events in reverse chronological order. If EventType is specified, this returns a list of device events for that EventType in reverse chronological order. . Defaults to None.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response only includes results beyond the token, up to the value specified by MaxResults. When the end of results is reached, the response has a value of null. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. The default value is 50. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.event.list_all(ctx, device_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.event.list_all device_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_device_events",
        op_kwargs={
            "DeviceArn": device_arn,
            "EventType": event_type,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    approval_rule_template_name: str,
    new_rule_content: str,
    existing_rule_content_sha256: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the content of an approval rule template. You can change the number of required approvals, the membership of the approval rule, and whether an approval pool is defined.

    Args:
        approval_rule_template_name(str): The name of the approval rule template where you want to update the content of the rule. .
        new_rule_content(str): The content that replaces the existing content of the rule. Content statements must be complete. You cannot provide only the changes.
        existing_rule_content_sha256(str, optional): The SHA-256 hash signature for the content of the approval rule. You can retrieve this information by using GetPullRequest. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.approval_rule_template.content.update(
                ctx, approval_rule_template_name=value, new_rule_content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.approval_rule_template.content.update approval_rule_template_name=value, new_rule_content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="update_approval_rule_template_content",
        op_kwargs={
            "approvalRuleTemplateName": approval_rule_template_name,
            "newRuleContent": new_rule_content,
            "existingRuleContentSha256": existing_rule_content_sha256,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"exit_": "exit"}


async def enter(
    hub,
    ctx,
    auto_scaling_group_name: str,
    should_decrement_desired_capacity: bool,
    instance_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Moves the specified instances into the standby state. If you choose to decrement the desired capacity of the Auto Scaling group, the instances can enter standby as long as the desired capacity of the Auto Scaling group after the instances are placed into standby is equal to or greater than the minimum capacity of the group. If you choose not to decrement the desired capacity of the Auto Scaling group, the Auto Scaling group launches new instances to replace the instances on standby. For more information, see Temporarily removing instances from your Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.

    Args:
        instance_ids(List, optional): The IDs of the instances. You can specify up to 20 instances. Defaults to None.
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        should_decrement_desired_capacity(bool): Indicates whether to decrement the desired capacity of the Auto Scaling group by the number of instances moved to Standby mode.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.standby.enter(
                ctx, auto_scaling_group_name=value, should_decrement_desired_capacity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.standby.enter auto_scaling_group_name=value, should_decrement_desired_capacity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="enter_standby",
        op_kwargs={
            "InstanceIds": instance_ids,
            "AutoScalingGroupName": auto_scaling_group_name,
            "ShouldDecrementDesiredCapacity": should_decrement_desired_capacity,
        },
    )


async def exit_(
    hub, ctx, auto_scaling_group_name: str, instance_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Moves the specified instances out of the standby state. After you put the instances back in service, the desired capacity is incremented. For more information, see Temporarily removing instances from your Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.

    Args:
        instance_ids(List, optional): The IDs of the instances. You can specify up to 20 instances. Defaults to None.
        auto_scaling_group_name(str): The name of the Auto Scaling group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.standby.exit(ctx, auto_scaling_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.standby.exit auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="exit_standby",
        op_kwargs={
            "InstanceIds": instance_ids,
            "AutoScalingGroupName": auto_scaling_group_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def run(hub, ctx, pipeline_activity: Dict, payloads: List) -> Dict:
    r"""
    **Autogenerated function**

    Simulates the results of running a pipeline activity on a message payload.

    Args:
        pipeline_activity(Dict): The pipeline activity that is run. This must not be a channel activity or a data store activity because these activities are used in a pipeline only to load the original message and to store the (possibly) transformed message. If a Lambda activity is specified, only short-running Lambda functions (those with a timeout of less than 30 seconds or less) can be used.
        payloads(List): The sample message payloads on which the pipeline activity is run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.pipeline.activity.run(
                ctx, pipeline_activity=value, payloads=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.pipeline.activity.run pipeline_activity=value, payloads=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="run_pipeline_activity",
        op_kwargs={"pipelineActivity": pipeline_activity, "payloads": payloads},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Applies a key-value pair to an AWS resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to apply the tag to.
        tags(List): The tags to apply.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes a tag from an AWS resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to remove the tag from.
        keys(List): The keys in the key-value pair in the tag to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.resource.untag(ctx, resource_arn=value, keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.resource.untag resource_arn=value, keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Keys": keys},
    )
